@@ -6,7 +6,7 @@ use utf8;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 with qw( CLDR::Number::Role::Base );
 
@@ -53,7 +53,7 @@ CLDR::Number - Localized number formatters using the Unicode CLDR
 
 =head1 VERSION
 
-This document describes CLDR::Number v0.11, built with Unicode CLDR v27.0.1.
+This document describes CLDR::Number v0.12, built with Unicode CLDR v27.0.1.
 
 =head1 SYNOPSIS
 
@@ -201,6 +201,15 @@ Examples: C<+> (plus sign) for B<root>, B<en>, and most locales
 
 Examples: C<-> (hyphen-minus) for B<root>, B<en>, and most locales
 
+=item infinity
+
+Examples: C<∞> (infinity) for B<root>, B<en>, and almost all locales
+
+=item nan
+
+Examples: C<NaN> for B<root>, B<en>, and most locales; many other variations for
+individual locales like C<не число> for B<ru> and C<非數值> for B<zh-Hant>
+
 =item cldr_version
 
 Value: C<27.0.1>
